# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
Intf module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_intf.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _Intf
else:
    import _Intf

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _Intf.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _Intf.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Intf.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Intf.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _Intf.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _Intf.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _Intf.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _Intf.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _Intf.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _Intf.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Intf.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _Intf.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _Intf.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Intf.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Intf.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Intf.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _Intf.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _Intf:
_Intf.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _Intf.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.Bnd
import OCC.Core.TColgp
import OCC.Core.BVH

from enum import IntEnum
from OCC.Core.Exception import *

Intf_EXTERNAL = _Intf.Intf_EXTERNAL
Intf_FACE = _Intf.Intf_FACE
Intf_EDGE = _Intf.Intf_EDGE
Intf_VERTEX = _Intf.Intf_VERTEX


class Intf_PIType(IntEnum):
	Intf_EXTERNAL = 0
	Intf_FACE = 1
	Intf_EDGE = 2
	Intf_VERTEX = 3
Intf_EXTERNAL = Intf_PIType.Intf_EXTERNAL
Intf_FACE = Intf_PIType.Intf_FACE
Intf_EDGE = Intf_PIType.Intf_EDGE
Intf_VERTEX = Intf_PIType.Intf_VERTEX

class Intf_Array1OfLin(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< gp_Lin >::iterator":
        return _Intf.Intf_Array1OfLin_begin(self)

    def end(self) -> "NCollection_Array1< gp_Lin >::iterator":
        return _Intf.Intf_Array1OfLin_end(self)

    def cbegin(self) -> "NCollection_Array1< gp_Lin >::const_iterator":
        return _Intf.Intf_Array1OfLin_cbegin(self)

    def cend(self) -> "NCollection_Array1< gp_Lin >::const_iterator":
        return _Intf.Intf_Array1OfLin_cend(self)

    def __init__(self, *args):
        _Intf.Intf_Array1OfLin_swiginit(self, _Intf.new_Intf_Array1OfLin(*args))

    def Init(self, theValue: "gp_Lin") -> "void":
        return _Intf.Intf_Array1OfLin_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _Intf.Intf_Array1OfLin_Size(self)

    def Length(self) -> "Standard_Integer":
        return _Intf.Intf_Array1OfLin_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _Intf.Intf_Array1OfLin_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _Intf.Intf_Array1OfLin_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _Intf.Intf_Array1OfLin_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _Intf.Intf_Array1OfLin_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _Intf.Intf_Array1OfLin_IsAllocated(self)

    def Assign(self, theOther: "Intf_Array1OfLin") -> "NCollection_Array1< gp_Lin > &":
        return _Intf.Intf_Array1OfLin_Assign(self, theOther)

    def Move(self, theOther: "Intf_Array1OfLin") -> "NCollection_Array1< gp_Lin > &":
        return _Intf.Intf_Array1OfLin_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< gp_Lin > &":
        return _Intf.Intf_Array1OfLin_Set(self, *args)

    def First(self) -> "gp_Lin const &":
        return _Intf.Intf_Array1OfLin_First(self)

    def ChangeFirst(self) -> "gp_Lin &":
        return _Intf.Intf_Array1OfLin_ChangeFirst(self)

    def Last(self) -> "gp_Lin const &":
        return _Intf.Intf_Array1OfLin_Last(self)

    def ChangeLast(self) -> "gp_Lin &":
        return _Intf.Intf_Array1OfLin_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "gp_Lin const &":
        return _Intf.Intf_Array1OfLin_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "gp_Lin &":
        return _Intf.Intf_Array1OfLin_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "gp_Lin &":
        return _Intf.Intf_Array1OfLin___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "gp_Lin") -> "void":
        return _Intf.Intf_Array1OfLin_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _Intf.Intf_Array1OfLin_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _Intf.delete_Intf_Array1OfLin

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register Intf_Array1OfLin in _Intf:
_Intf.Intf_Array1OfLin_swigregister(Intf_Array1OfLin)

class Intf_SeqOfSectionLine(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< Intf_SectionLine >::iterator":
        return _Intf.Intf_SeqOfSectionLine_begin(self)

    def end(self) -> "NCollection_Sequence< Intf_SectionLine >::iterator":
        return _Intf.Intf_SeqOfSectionLine_end(self)

    def cbegin(self) -> "NCollection_Sequence< Intf_SectionLine >::const_iterator":
        return _Intf.Intf_SeqOfSectionLine_cbegin(self)

    def cend(self) -> "NCollection_Sequence< Intf_SectionLine >::const_iterator":
        return _Intf.Intf_SeqOfSectionLine_cend(self)

    def __init__(self, *args):
        _Intf.Intf_SeqOfSectionLine_swiginit(self, _Intf.new_Intf_SeqOfSectionLine(*args))

    def Size(self) -> "Standard_Integer":
        return _Intf.Intf_SeqOfSectionLine_Size(self)

    def Length(self) -> "Standard_Integer":
        return _Intf.Intf_SeqOfSectionLine_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _Intf.Intf_SeqOfSectionLine_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _Intf.Intf_SeqOfSectionLine_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _Intf.Intf_SeqOfSectionLine_IsEmpty(self)

    def Reverse(self) -> "void":
        return _Intf.Intf_SeqOfSectionLine_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _Intf.Intf_SeqOfSectionLine_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _Intf.Intf_SeqOfSectionLine_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _Intf.Intf_SeqOfSectionLine_Clear(self, theAllocator)

    def Assign(self, theOther: "Intf_SeqOfSectionLine") -> "NCollection_Sequence< Intf_SectionLine > &":
        return _Intf.Intf_SeqOfSectionLine_Assign(self, theOther)

    def Set(self, theOther: "Intf_SeqOfSectionLine") -> "NCollection_Sequence< Intf_SectionLine > &":
        return _Intf.Intf_SeqOfSectionLine_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _Intf.Intf_SeqOfSectionLine_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _Intf.Intf_SeqOfSectionLine_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _Intf.Intf_SeqOfSectionLine_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _Intf.Intf_SeqOfSectionLine_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _Intf.Intf_SeqOfSectionLine_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "Intf_SeqOfSectionLine") -> "void":
        return _Intf.Intf_SeqOfSectionLine_Split(self, theIndex, theSeq)

    def First(self) -> "Intf_SectionLine const &":
        return _Intf.Intf_SeqOfSectionLine_First(self)

    def ChangeFirst(self) -> "Intf_SectionLine &":
        return _Intf.Intf_SeqOfSectionLine_ChangeFirst(self)

    def Last(self) -> "Intf_SectionLine const &":
        return _Intf.Intf_SeqOfSectionLine_Last(self)

    def ChangeLast(self) -> "Intf_SectionLine &":
        return _Intf.Intf_SeqOfSectionLine_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "Intf_SectionLine const &":
        return _Intf.Intf_SeqOfSectionLine_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "Intf_SectionLine &":
        return _Intf.Intf_SeqOfSectionLine_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "Intf_SectionLine &":
        return _Intf.Intf_SeqOfSectionLine___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "Intf_SectionLine") -> "void":
        return _Intf.Intf_SeqOfSectionLine_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _Intf.delete_Intf_SeqOfSectionLine

    def __len__(self):
        return self.Size()


# Register Intf_SeqOfSectionLine in _Intf:
_Intf.Intf_SeqOfSectionLine_swigregister(Intf_SeqOfSectionLine)

def Intf_SeqOfSectionLine_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _Intf.Intf_SeqOfSectionLine_delNode(theNode, theAl)

class Intf_SeqOfSectionPoint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< Intf_SectionPoint >::iterator":
        return _Intf.Intf_SeqOfSectionPoint_begin(self)

    def end(self) -> "NCollection_Sequence< Intf_SectionPoint >::iterator":
        return _Intf.Intf_SeqOfSectionPoint_end(self)

    def cbegin(self) -> "NCollection_Sequence< Intf_SectionPoint >::const_iterator":
        return _Intf.Intf_SeqOfSectionPoint_cbegin(self)

    def cend(self) -> "NCollection_Sequence< Intf_SectionPoint >::const_iterator":
        return _Intf.Intf_SeqOfSectionPoint_cend(self)

    def __init__(self, *args):
        _Intf.Intf_SeqOfSectionPoint_swiginit(self, _Intf.new_Intf_SeqOfSectionPoint(*args))

    def Size(self) -> "Standard_Integer":
        return _Intf.Intf_SeqOfSectionPoint_Size(self)

    def Length(self) -> "Standard_Integer":
        return _Intf.Intf_SeqOfSectionPoint_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _Intf.Intf_SeqOfSectionPoint_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _Intf.Intf_SeqOfSectionPoint_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _Intf.Intf_SeqOfSectionPoint_IsEmpty(self)

    def Reverse(self) -> "void":
        return _Intf.Intf_SeqOfSectionPoint_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _Intf.Intf_SeqOfSectionPoint_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _Intf.Intf_SeqOfSectionPoint_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _Intf.Intf_SeqOfSectionPoint_Clear(self, theAllocator)

    def Assign(self, theOther: "Intf_SeqOfSectionPoint") -> "NCollection_Sequence< Intf_SectionPoint > &":
        return _Intf.Intf_SeqOfSectionPoint_Assign(self, theOther)

    def Set(self, theOther: "Intf_SeqOfSectionPoint") -> "NCollection_Sequence< Intf_SectionPoint > &":
        return _Intf.Intf_SeqOfSectionPoint_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _Intf.Intf_SeqOfSectionPoint_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _Intf.Intf_SeqOfSectionPoint_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _Intf.Intf_SeqOfSectionPoint_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _Intf.Intf_SeqOfSectionPoint_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _Intf.Intf_SeqOfSectionPoint_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "Intf_SeqOfSectionPoint") -> "void":
        return _Intf.Intf_SeqOfSectionPoint_Split(self, theIndex, theSeq)

    def First(self) -> "Intf_SectionPoint const &":
        return _Intf.Intf_SeqOfSectionPoint_First(self)

    def ChangeFirst(self) -> "Intf_SectionPoint &":
        return _Intf.Intf_SeqOfSectionPoint_ChangeFirst(self)

    def Last(self) -> "Intf_SectionPoint const &":
        return _Intf.Intf_SeqOfSectionPoint_Last(self)

    def ChangeLast(self) -> "Intf_SectionPoint &":
        return _Intf.Intf_SeqOfSectionPoint_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "Intf_SectionPoint const &":
        return _Intf.Intf_SeqOfSectionPoint_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "Intf_SectionPoint &":
        return _Intf.Intf_SeqOfSectionPoint_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "Intf_SectionPoint &":
        return _Intf.Intf_SeqOfSectionPoint___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "Intf_SectionPoint") -> "void":
        return _Intf.Intf_SeqOfSectionPoint_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _Intf.delete_Intf_SeqOfSectionPoint

    def __len__(self):
        return self.Size()


# Register Intf_SeqOfSectionPoint in _Intf:
_Intf.Intf_SeqOfSectionPoint_swigregister(Intf_SeqOfSectionPoint)

def Intf_SeqOfSectionPoint_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _Intf.Intf_SeqOfSectionPoint_delNode(theNode, theAl)

class Intf_SeqOfTangentZone(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< Intf_TangentZone >::iterator":
        return _Intf.Intf_SeqOfTangentZone_begin(self)

    def end(self) -> "NCollection_Sequence< Intf_TangentZone >::iterator":
        return _Intf.Intf_SeqOfTangentZone_end(self)

    def cbegin(self) -> "NCollection_Sequence< Intf_TangentZone >::const_iterator":
        return _Intf.Intf_SeqOfTangentZone_cbegin(self)

    def cend(self) -> "NCollection_Sequence< Intf_TangentZone >::const_iterator":
        return _Intf.Intf_SeqOfTangentZone_cend(self)

    def __init__(self, *args):
        _Intf.Intf_SeqOfTangentZone_swiginit(self, _Intf.new_Intf_SeqOfTangentZone(*args))

    def Size(self) -> "Standard_Integer":
        return _Intf.Intf_SeqOfTangentZone_Size(self)

    def Length(self) -> "Standard_Integer":
        return _Intf.Intf_SeqOfTangentZone_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _Intf.Intf_SeqOfTangentZone_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _Intf.Intf_SeqOfTangentZone_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _Intf.Intf_SeqOfTangentZone_IsEmpty(self)

    def Reverse(self) -> "void":
        return _Intf.Intf_SeqOfTangentZone_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _Intf.Intf_SeqOfTangentZone_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _Intf.Intf_SeqOfTangentZone_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _Intf.Intf_SeqOfTangentZone_Clear(self, theAllocator)

    def Assign(self, theOther: "Intf_SeqOfTangentZone") -> "NCollection_Sequence< Intf_TangentZone > &":
        return _Intf.Intf_SeqOfTangentZone_Assign(self, theOther)

    def Set(self, theOther: "Intf_SeqOfTangentZone") -> "NCollection_Sequence< Intf_TangentZone > &":
        return _Intf.Intf_SeqOfTangentZone_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _Intf.Intf_SeqOfTangentZone_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _Intf.Intf_SeqOfTangentZone_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _Intf.Intf_SeqOfTangentZone_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _Intf.Intf_SeqOfTangentZone_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _Intf.Intf_SeqOfTangentZone_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "Intf_SeqOfTangentZone") -> "void":
        return _Intf.Intf_SeqOfTangentZone_Split(self, theIndex, theSeq)

    def First(self) -> "Intf_TangentZone const &":
        return _Intf.Intf_SeqOfTangentZone_First(self)

    def ChangeFirst(self) -> "Intf_TangentZone &":
        return _Intf.Intf_SeqOfTangentZone_ChangeFirst(self)

    def Last(self) -> "Intf_TangentZone const &":
        return _Intf.Intf_SeqOfTangentZone_Last(self)

    def ChangeLast(self) -> "Intf_TangentZone &":
        return _Intf.Intf_SeqOfTangentZone_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "Intf_TangentZone const &":
        return _Intf.Intf_SeqOfTangentZone_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "Intf_TangentZone &":
        return _Intf.Intf_SeqOfTangentZone_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "Intf_TangentZone &":
        return _Intf.Intf_SeqOfTangentZone___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "Intf_TangentZone") -> "void":
        return _Intf.Intf_SeqOfTangentZone_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _Intf.delete_Intf_SeqOfTangentZone

    def __len__(self):
        return self.Size()


# Register Intf_SeqOfTangentZone in _Intf:
_Intf.Intf_SeqOfTangentZone_swigregister(Intf_SeqOfTangentZone)

def Intf_SeqOfTangentZone_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _Intf.Intf_SeqOfTangentZone_delNode(theNode, theAl)

class intf(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Contain(*args) -> "Standard_Boolean":
        r"""
        Compute if the triangle <p1> <p2> <p3> contain <thepnt>.

        Parameters
        ----------
        P1: gp_Pnt
        P2: gp_Pnt
        P3: gp_Pnt
        ThePnt: gp_Pnt

        Returns
        -------
        bool

        """
        return _Intf.intf_Contain(*args)

    @staticmethod
    def PlaneEquation(*args) -> "Standard_Real &":
        r"""
        Computes the interference between two polygons in 2d. result : points of intersections and zones of tangence. computes the interference between a polygon or a straight line and a polyhedron. points of intersection and zones of tangence. give the plane equation of the triangle <p1> <p2> <p3>.

        Parameters
        ----------
        P1: gp_Pnt
        P2: gp_Pnt
        P3: gp_Pnt
        NormalVector: gp_XYZ

        Returns
        -------
        PolarDistance: float

        """
        return _Intf.intf_PlaneEquation(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _Intf.intf_swiginit(self, _Intf.new_intf())
    __swig_destroy__ = _Intf.delete_intf

# Register intf in _Intf:
_Intf.intf_swigregister(intf)

def intf_Contain(*args) -> "Standard_Boolean":
    r"""
    Compute if the triangle <p1> <p2> <p3> contain <thepnt>.

    Parameters
    ----------
    P1: gp_Pnt
    P2: gp_Pnt
    P3: gp_Pnt
    ThePnt: gp_Pnt

    Returns
    -------
    bool

    """
    return _Intf.intf_Contain(*args)

def intf_PlaneEquation(*args) -> "Standard_Real &":
    r"""
    Computes the interference between two polygons in 2d. result : points of intersections and zones of tangence. computes the interference between a polygon or a straight line and a polyhedron. points of intersection and zones of tangence. give the plane equation of the triangle <p1> <p2> <p3>.

    Parameters
    ----------
    P1: gp_Pnt
    P2: gp_Pnt
    P3: gp_Pnt
    NormalVector: gp_XYZ

    Returns
    -------
    PolarDistance: float

    """
    return _Intf.intf_PlaneEquation(*args)

class Intf_Interference(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Contains(self, *args) -> "Standard_Boolean":
        r"""
        Tests if the polylines of intersection or the zones of tangence contain the point of intersection <thepnt>.

        Parameters
        ----------
        ThePnt: Intf_SectionPoint

        Returns
        -------
        bool

        """
        return _Intf.Intf_Interference_Contains(self, *args)

    def Dump(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _Intf.Intf_Interference_Dump(self, *args)

    def GetTolerance(self, *args) -> "Standard_Real":
        r"""
        Gives the tolerance used for the calculation.

        Returns
        -------
        float

        """
        return _Intf.Intf_Interference_GetTolerance(self, *args)

    def Insert(self, *args) -> "void":
        r"""
        Inserts a new zone of tangence in the current list of tangent zones of the interference and returns true when done.

        Parameters
        ----------
        TheZone: Intf_TangentZone

        Returns
        -------
        bool
        Insert a new segment of intersection in the current list of polylines of intersection of the interference.

        Parameters
        ----------
        pdeb: Intf_SectionPoint
        pfin: Intf_SectionPoint

        Returns
        -------
        None

        """
        return _Intf.Intf_Interference_Insert(self, *args)

    def LineValue(self, *args) -> "Intf_SectionLine const &":
        r"""
        Gives the polyline of intersection at address <index> in the interference.

        Parameters
        ----------
        Index: int

        Returns
        -------
        Intf_SectionLine

        """
        return _Intf.Intf_Interference_LineValue(self, *args)

    def NbSectionLines(self, *args) -> "Standard_Integer":
        r"""
        Gives the number of polylines of intersection in the interference.

        Returns
        -------
        int

        """
        return _Intf.Intf_Interference_NbSectionLines(self, *args)

    def NbSectionPoints(self, *args) -> "Standard_Integer":
        r"""
        Gives the number of points of intersection in the interference.

        Returns
        -------
        int

        """
        return _Intf.Intf_Interference_NbSectionPoints(self, *args)

    def NbTangentZones(self, *args) -> "Standard_Integer":
        r"""
        Gives the number of zones of tangence in the interference.

        Returns
        -------
        int

        """
        return _Intf.Intf_Interference_NbTangentZones(self, *args)

    def PntValue(self, *args) -> "Intf_SectionPoint const &":
        r"""
        Gives the point of intersection of address index in the interference.

        Parameters
        ----------
        Index: int

        Returns
        -------
        Intf_SectionPoint

        """
        return _Intf.Intf_Interference_PntValue(self, *args)

    def ZoneValue(self, *args) -> "Intf_TangentZone const &":
        r"""
        Gives the zone of tangence at address index in the interference.

        Parameters
        ----------
        Index: int

        Returns
        -------
        Intf_TangentZone

        """
        return _Intf.Intf_Interference_ZoneValue(self, *args)

    __repr__ = _dumps_object


# Register Intf_Interference in _Intf:
_Intf.Intf_Interference_swigregister(Intf_Interference)

class Intf_Polygon2d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Bounding(self, *args) -> "Bnd_Box2d const &":
        r"""
        Returns the bounding box of the polygon.

        Returns
        -------
        Bnd_Box2d

        """
        return _Intf.Intf_Polygon2d_Bounding(self, *args)

    def Closed(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the polyline is closed.

        Returns
        -------
        bool

        """
        return _Intf.Intf_Polygon2d_Closed(self, *args)

    def DeflectionOverEstimation(self, *args) -> "Standard_Real":
        r"""
        Returns the tolerance of the polygon.

        Returns
        -------
        float

        """
        return _Intf.Intf_Polygon2d_DeflectionOverEstimation(self, *args)

    def NbSegments(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of segments in the polyline.

        Returns
        -------
        int

        """
        return _Intf.Intf_Polygon2d_NbSegments(self, *args)

    def Segment(self, *args) -> "void":
        r"""
        Returns the points of the segment <index> in the polygon.

        Parameters
        ----------
        theIndex: int
        theBegin: gp_Pnt2d
        theEnd: gp_Pnt2d

        Returns
        -------
        None

        """
        return _Intf.Intf_Polygon2d_Segment(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Intf.delete_Intf_Polygon2d

# Register Intf_Polygon2d in _Intf:
_Intf.Intf_Polygon2d_swigregister(Intf_Polygon2d)

class Intf_SectionLine(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs an empty sectionline.

        Returns
        -------
        None
        Copies a sectionline.

        Parameters
        ----------
        Other: Intf_SectionLine

        Returns
        -------
        None

        """
        _Intf.Intf_SectionLine_swiginit(self, _Intf.new_Intf_SectionLine(*args))

    def Append(self, *args) -> "void":
        r"""
        Adds a point at the end of the sectionline.

        Parameters
        ----------
        Pi: Intf_SectionPoint

        Returns
        -------
        None
        Concatenates the sectionline <ls> at the end of the sectionline <self>.

        Parameters
        ----------
        LS: Intf_SectionLine

        Returns
        -------
        None

        """
        return _Intf.Intf_SectionLine_Append(self, *args)

    def Close(self, *args) -> "void":
        r"""
        Closes the sectionline.

        Returns
        -------
        None

        """
        return _Intf.Intf_SectionLine_Close(self, *args)

    def Contains(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if thepi is in the sectionline <self>.

        Parameters
        ----------
        ThePI: Intf_SectionPoint

        Returns
        -------
        bool

        """
        return _Intf.Intf_SectionLine_Contains(self, *args)

    def Dump(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Indent: int

        Returns
        -------
        None

        """
        return _Intf.Intf_SectionLine_Dump(self, *args)

    def GetPoint(self, *args) -> "Intf_SectionPoint const &":
        r"""
        Gives the point of intersection of address <index> in the sectionline.

        Parameters
        ----------
        Index: int

        Returns
        -------
        Intf_SectionPoint

        """
        return _Intf.Intf_SectionLine_GetPoint(self, *args)

    def IsClosed(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the sectionline is closed.

        Returns
        -------
        bool

        """
        return _Intf.Intf_SectionLine_IsClosed(self, *args)

    def IsEnd(self, *args) -> "Standard_Integer":
        r"""
        Checks if <thepi> is an end of the sectionline. returns 1 for the beginning, 2 for the end, otherwise 0.

        Parameters
        ----------
        ThePI: Intf_SectionPoint

        Returns
        -------
        int

        """
        return _Intf.Intf_SectionLine_IsEnd(self, *args)

    def IsEqual(self, *args) -> "Standard_Boolean":
        r"""
        Compares two sectionlines.

        Parameters
        ----------
        Other: Intf_SectionLine

        Returns
        -------
        bool

        """
        return _Intf.Intf_SectionLine_IsEqual(self, *args)

    def NumberOfPoints(self, *args) -> "Standard_Integer":
        r"""
        Returns number of points in this sectionline.

        Returns
        -------
        int

        """
        return _Intf.Intf_SectionLine_NumberOfPoints(self, *args)

    def Prepend(self, *args) -> "void":
        r"""
        Adds a point to the beginning of the sectionline <self>.

        Parameters
        ----------
        Pi: Intf_SectionPoint

        Returns
        -------
        None
        Concatenates a sectionline <ls> at the beginning of the sectionline <self>.

        Parameters
        ----------
        LS: Intf_SectionLine

        Returns
        -------
        None

        """
        return _Intf.Intf_SectionLine_Prepend(self, *args)

    def Reverse(self, *args) -> "void":
        r"""
        Reverses the order of the elements of the sectionline.

        Returns
        -------
        None

        """
        return _Intf.Intf_SectionLine_Reverse(self, *args)

    def __eq_wrapper__(self, other: "Intf_SectionLine") -> "bool":
        return _Intf.Intf_SectionLine___eq_wrapper__(self, other)

    def __eq__(self, right):
        try:
            return self.__eq_wrapper__(right)
        except:
            return False


    __repr__ = _dumps_object

    __swig_destroy__ = _Intf.delete_Intf_SectionLine

# Register Intf_SectionLine in _Intf:
_Intf.Intf_SectionLine_swigregister(Intf_SectionLine)

class Intf_SectionPoint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        Builds a sectionpoint with the respective dimensions (vertex edge or face) of the concerned arguments and their addresses in the topological structure.

        Parameters
        ----------
        Where: gp_Pnt
        DimeO: Intf_PIType
        AddrO1: int
        AddrO2: int
        ParamO: float
        DimeT: Intf_PIType
        AddrT1: int
        AddrT2: int
        ParamT: float
        Incid: float

        Returns
        -------
        None
        Builds a sectionpoint 2d with the respective dimensions (vertex or edge) of the concerned arguments and their addresses in the topological structure.

        Parameters
        ----------
        Where: gp_Pnt2d
        DimeO: Intf_PIType
        AddrO1: int
        ParamO: float
        DimeT: Intf_PIType
        AddrT1: int
        ParamT: float
        Incid: float

        Returns
        -------
        None

        """
        _Intf.Intf_SectionPoint_swiginit(self, _Intf.new_Intf_SectionPoint(*args))

    def Dump(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Indent: int

        Returns
        -------
        None

        """
        return _Intf.Intf_SectionPoint_Dump(self, *args)

    def Incidence(self, *args) -> "Standard_Real":
        r"""
        Gives the incidence at this section point. the incidence between the two triangles is given by the cosine. the best incidence is 0. (pi/2). the worst is 1. (null angle).

        Returns
        -------
        float

        """
        return _Intf.Intf_SectionPoint_Incidence(self, *args)

    def InfoFirst(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Dim: Intf_PIType

        Returns
        -------
        Add1: int
        Add2: int
        Param: float
        Gives the datas about the first argument of the interference.

        Parameters
        ----------
        Dim: Intf_PIType

        Returns
        -------
        Addr: int
        Param: float

        """
        return _Intf.Intf_SectionPoint_InfoFirst(self, *args)

    def InfoSecond(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Dim: Intf_PIType

        Returns
        -------
        Add1: int
        Add2: int
        Param: float
        Gives the datas about the second argument of the interference.

        Parameters
        ----------
        Dim: Intf_PIType

        Returns
        -------
        Addr: int
        Param: float

        """
        return _Intf.Intf_SectionPoint_InfoSecond(self, *args)

    def IsEqual(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the two sectionpoint have the same logical informations.

        Parameters
        ----------
        Other: Intf_SectionPoint

        Returns
        -------
        bool

        """
        return _Intf.Intf_SectionPoint_IsEqual(self, *args)

    def IsOnSameEdge(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the two sectionpoints are on the same edge of the first or the second element.

        Parameters
        ----------
        Other: Intf_SectionPoint

        Returns
        -------
        bool

        """
        return _Intf.Intf_SectionPoint_IsOnSameEdge(self, *args)

    def Merge(self, *args) -> "void":
        r"""
        Merges two sectionpoints.

        Parameters
        ----------
        Other: Intf_SectionPoint

        Returns
        -------
        None

        """
        return _Intf.Intf_SectionPoint_Merge(self, *args)

    def ParamOnFirst(self, *args) -> "Standard_Real":
        r"""
        Returns the cumulated parameter of the sectionpoint on the first element.

        Returns
        -------
        float

        """
        return _Intf.Intf_SectionPoint_ParamOnFirst(self, *args)

    def ParamOnSecond(self, *args) -> "Standard_Real":
        r"""
        Returns the cumulated parameter of the section point on the second element.

        Returns
        -------
        float

        """
        return _Intf.Intf_SectionPoint_ParamOnSecond(self, *args)

    def Pnt(self, *args) -> "gp_Pnt const":
        r"""
        Returns the location of the sectionpoint.

        Returns
        -------
        gp_Pnt

        """
        return _Intf.Intf_SectionPoint_Pnt(self, *args)

    def TypeOnFirst(self, *args) -> "Intf_PIType":
        r"""
        Returns the type of the section point on the first element.

        Returns
        -------
        Intf_PIType

        """
        return _Intf.Intf_SectionPoint_TypeOnFirst(self, *args)

    def TypeOnSecond(self, *args) -> "Intf_PIType":
        r"""
        Returns the type of the section point on the second element.

        Returns
        -------
        Intf_PIType

        """
        return _Intf.Intf_SectionPoint_TypeOnSecond(self, *args)

    def __eq_wrapper__(self, other: "Intf_SectionPoint") -> "bool":
        return _Intf.Intf_SectionPoint___eq_wrapper__(self, other)

    def __eq__(self, right):
        try:
            return self.__eq_wrapper__(right)
        except:
            return False


    __repr__ = _dumps_object

    __swig_destroy__ = _Intf.delete_Intf_SectionPoint

# Register Intf_SectionPoint in _Intf:
_Intf.Intf_SectionPoint_swigregister(Intf_SectionPoint)

class Intf_TangentZone(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Builds an empty tangent zone.

        Returns
        -------
        None

        """
        _Intf.Intf_TangentZone_swiginit(self, _Intf.new_Intf_TangentZone(*args))

    def Append(self, *args) -> "void":
        r"""
        Adds a sectionpoint to the tangentzone.

        Parameters
        ----------
        Pi: Intf_SectionPoint

        Returns
        -------
        None
        Adds the tangentzone <tzi> to <self>.

        Parameters
        ----------
        Tzi: Intf_TangentZone

        Returns
        -------
        None

        """
        return _Intf.Intf_TangentZone_Append(self, *args)

    def Contains(self, *args) -> "Standard_Boolean":
        r"""
        Checks if <thepi> is in tangentzone.

        Parameters
        ----------
        ThePI: Intf_SectionPoint

        Returns
        -------
        bool

        """
        return _Intf.Intf_TangentZone_Contains(self, *args)

    def Dump(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Indent: int

        Returns
        -------
        None

        """
        return _Intf.Intf_TangentZone_Dump(self, *args)

    def GetPoint(self, *args) -> "Intf_SectionPoint const &":
        r"""
        Gives the sectionpoint of address <index> in the tangentzone.

        Parameters
        ----------
        Index: int

        Returns
        -------
        Intf_SectionPoint

        """
        return _Intf.Intf_TangentZone_GetPoint(self, *args)

    def HasCommonRange(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the tangentzone <other> has a common part with <self>.

        Parameters
        ----------
        Other: Intf_TangentZone

        Returns
        -------
        bool

        """
        return _Intf.Intf_TangentZone_HasCommonRange(self, *args)

    def InfoFirst(self, *args) -> "void":
        r"""
        Gives information about the first argument of the interference. (usable only for polygon).

        Parameters
        ----------

        Returns
        -------
        segMin: int
        paraMin: float
        segMax: int
        paraMax: float

        """
        return _Intf.Intf_TangentZone_InfoFirst(self, *args)

    def InfoSecond(self, *args) -> "void":
        r"""
        Gives informations about the second argument of the interference. (usable only for polygon).

        Parameters
        ----------

        Returns
        -------
        segMin: int
        paraMin: float
        segMax: int
        paraMax: float

        """
        return _Intf.Intf_TangentZone_InfoSecond(self, *args)

    def Insert(self, *args) -> "Standard_Boolean":
        r"""
        Inserts a sectionpoint in the tangentzone.

        Parameters
        ----------
        Pi: Intf_SectionPoint

        Returns
        -------
        bool

        """
        return _Intf.Intf_TangentZone_Insert(self, *args)

    def InsertAfter(self, *args) -> "void":
        r"""
        Inserts a sectionpoint after <index> in the tangentzone.

        Parameters
        ----------
        Index: int
        Pi: Intf_SectionPoint

        Returns
        -------
        None

        """
        return _Intf.Intf_TangentZone_InsertAfter(self, *args)

    def InsertBefore(self, *args) -> "void":
        r"""
        Inserts a sectionpoint before <index> in the tangentzone.

        Parameters
        ----------
        Index: int
        Pi: Intf_SectionPoint

        Returns
        -------
        None

        """
        return _Intf.Intf_TangentZone_InsertBefore(self, *args)

    def IsEqual(self, *args) -> "Standard_Boolean":
        r"""
        Compares two tangentzones.

        Parameters
        ----------
        Other: Intf_TangentZone

        Returns
        -------
        bool

        """
        return _Intf.Intf_TangentZone_IsEqual(self, *args)

    def NumberOfPoints(self, *args) -> "Standard_Integer":
        r"""
        Returns number of sectionpoint in this tangentzone.

        Returns
        -------
        int

        """
        return _Intf.Intf_TangentZone_NumberOfPoints(self, *args)

    def ParamOnFirst(self, *args) -> "void":
        r"""
        Gives the parameter range of the tangentzone on the first argument of the interference. (usable only for polygon).

        Parameters
        ----------

        Returns
        -------
        paraMin: float
        paraMax: float

        """
        return _Intf.Intf_TangentZone_ParamOnFirst(self, *args)

    def ParamOnSecond(self, *args) -> "void":
        r"""
        Gives the parameter range of the tangentzone on the second argument of the interference. (usable only for polygon).

        Parameters
        ----------

        Returns
        -------
        paraMin: float
        paraMax: float

        """
        return _Intf.Intf_TangentZone_ParamOnSecond(self, *args)

    def PolygonInsert(self, *args) -> "void":
        r"""
        Inserts a point in the polygonal tangentzone.

        Parameters
        ----------
        Pi: Intf_SectionPoint

        Returns
        -------
        None

        """
        return _Intf.Intf_TangentZone_PolygonInsert(self, *args)

    def RangeContains(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if <thepi> is in the parameter range of the tangentzone.

        Parameters
        ----------
        ThePI: Intf_SectionPoint

        Returns
        -------
        bool

        """
        return _Intf.Intf_TangentZone_RangeContains(self, *args)

    def __eq_wrapper__(self, other: "Intf_TangentZone") -> "bool":
        return _Intf.Intf_TangentZone___eq_wrapper__(self, other)

    def __eq__(self, right):
        try:
            return self.__eq_wrapper__(right)
        except:
            return False


    __repr__ = _dumps_object

    __swig_destroy__ = _Intf.delete_Intf_TangentZone

# Register Intf_TangentZone in _Intf:
_Intf.Intf_TangentZone_swigregister(Intf_TangentZone)

class Intf_Tool(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _Intf.Intf_Tool_swiginit(self, _Intf.new_Intf_Tool(*args))

    def BeginParam(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Parameters
        ----------
        SegmentNum: int

        Returns
        -------
        float

        """
        return _Intf.Intf_Tool_BeginParam(self, *args)

    def EndParam(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Parameters
        ----------
        SegmentNum: int

        Returns
        -------
        float

        """
        return _Intf.Intf_Tool_EndParam(self, *args)

    def Hypr2dBox(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theHypr2d: gp_Hypr2d
        bounding: Bnd_Box2d
        boxHypr: Bnd_Box2d

        Returns
        -------
        None

        """
        return _Intf.Intf_Tool_Hypr2dBox(self, *args)

    def HyprBox(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theHypr: gp_Hypr
        bounding: Bnd_Box
        boxHypr: Bnd_Box

        Returns
        -------
        None

        """
        return _Intf.Intf_Tool_HyprBox(self, *args)

    def Lin2dBox(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theLin2d: gp_Lin2d
        bounding: Bnd_Box2d
        boxLin: Bnd_Box2d

        Returns
        -------
        None

        """
        return _Intf.Intf_Tool_Lin2dBox(self, *args)

    def LinBox(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theLin: gp_Lin
        bounding: Bnd_Box
        boxLin: Bnd_Box

        Returns
        -------
        None

        """
        return _Intf.Intf_Tool_LinBox(self, *args)

    def NbSegments(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _Intf.Intf_Tool_NbSegments(self, *args)

    def Parab2dBox(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theParab2d: gp_Parab2d
        bounding: Bnd_Box2d
        boxHypr: Bnd_Box2d

        Returns
        -------
        None

        """
        return _Intf.Intf_Tool_Parab2dBox(self, *args)

    def ParabBox(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theParab: gp_Parab
        bounding: Bnd_Box
        boxHypr: Bnd_Box

        Returns
        -------
        None

        """
        return _Intf.Intf_Tool_ParabBox(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Intf.delete_Intf_Tool

# Register Intf_Tool in _Intf:
_Intf.Intf_Tool_swigregister(Intf_Tool)

class Intf_InterferencePolygon2d(Intf_Interference):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs an empty interference of polygon.

        Returns
        -------
        None
        Constructs and computes an interference between two polygons.

        Parameters
        ----------
        Obje1: Intf_Polygon2d
        Obje2: Intf_Polygon2d

        Returns
        -------
        None
        Constructs and computes the auto interference of a polygon.

        Parameters
        ----------
        Obje: Intf_Polygon2d

        Returns
        -------
        None

        """
        _Intf.Intf_InterferencePolygon2d_swiginit(self, _Intf.new_Intf_InterferencePolygon2d(*args))

    def Perform(self, *args) -> "void":
        r"""
        Computes an interference between two polygons.

        Parameters
        ----------
        Obje1: Intf_Polygon2d
        Obje2: Intf_Polygon2d

        Returns
        -------
        None
        Computes the self interference of a polygon.

        Parameters
        ----------
        Obje: Intf_Polygon2d

        Returns
        -------
        None

        """
        return _Intf.Intf_InterferencePolygon2d_Perform(self, *args)

    def Pnt2dValue(self, *args) -> "gp_Pnt2d":
        r"""
        Gives the geometrical 2d point of the intersection point at address <index> in the interference.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Pnt2d

        """
        return _Intf.Intf_InterferencePolygon2d_Pnt2dValue(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Intf.delete_Intf_InterferencePolygon2d

# Register Intf_InterferencePolygon2d in _Intf:
_Intf.Intf_InterferencePolygon2d_swigregister(Intf_InterferencePolygon2d)








# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
LocalAnalysis module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_localanalysis.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _LocalAnalysis
else:
    import _LocalAnalysis

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _LocalAnalysis.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _LocalAnalysis.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _LocalAnalysis.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _LocalAnalysis.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _LocalAnalysis.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _LocalAnalysis.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _LocalAnalysis.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _LocalAnalysis.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _LocalAnalysis.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _LocalAnalysis.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _LocalAnalysis.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _LocalAnalysis.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _LocalAnalysis.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _LocalAnalysis.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _LocalAnalysis.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _LocalAnalysis.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _LocalAnalysis.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _LocalAnalysis:
_LocalAnalysis.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _LocalAnalysis.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Geom
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Geom2d
import OCC.Core.GeomLProp

from enum import IntEnum
from OCC.Core.Exception import *

LocalAnalysis_NullFirstDerivative = _LocalAnalysis.LocalAnalysis_NullFirstDerivative
LocalAnalysis_NullSecondDerivative = _LocalAnalysis.LocalAnalysis_NullSecondDerivative
LocalAnalysis_TangentNotDefined = _LocalAnalysis.LocalAnalysis_TangentNotDefined
LocalAnalysis_NormalNotDefined = _LocalAnalysis.LocalAnalysis_NormalNotDefined
LocalAnalysis_CurvatureNotDefined = _LocalAnalysis.LocalAnalysis_CurvatureNotDefined


class LocalAnalysis_StatusErrorType(IntEnum):
	LocalAnalysis_NullFirstDerivative = 0
	LocalAnalysis_NullSecondDerivative = 1
	LocalAnalysis_TangentNotDefined = 2
	LocalAnalysis_NormalNotDefined = 3
	LocalAnalysis_CurvatureNotDefined = 4
LocalAnalysis_NullFirstDerivative = LocalAnalysis_StatusErrorType.LocalAnalysis_NullFirstDerivative
LocalAnalysis_NullSecondDerivative = LocalAnalysis_StatusErrorType.LocalAnalysis_NullSecondDerivative
LocalAnalysis_TangentNotDefined = LocalAnalysis_StatusErrorType.LocalAnalysis_TangentNotDefined
LocalAnalysis_NormalNotDefined = LocalAnalysis_StatusErrorType.LocalAnalysis_NormalNotDefined
LocalAnalysis_CurvatureNotDefined = LocalAnalysis_StatusErrorType.LocalAnalysis_CurvatureNotDefined

class localanalysis(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    __repr__ = _dumps_object


    def __init__(self):
        _LocalAnalysis.localanalysis_swiginit(self, _LocalAnalysis.new_localanalysis())
    __swig_destroy__ = _LocalAnalysis.delete_localanalysis

# Register localanalysis in _LocalAnalysis:
_LocalAnalysis.localanalysis_swigregister(localanalysis)

class LocalAnalysis_CurveContinuity(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        -u1 is the parameter of the point on curv1 -u2 is the parameter of the point on curv2 -order is the required continuity: geomabs_c0 geomabs_c1 geomabs_c2 geomabs_g1 geomabs_g2 //! -epsnul is used to detect a a vector with nul magnitude (in mm) //! -epsc0 is used for c0 continuity to confuse two points (in mm) //! -epsc1 is an angular tolerance in radians used for c1 continuity to compare the angle between the first derivatives //! -epsc2 is an angular tolerance in radians used for c2 continuity to compare the angle between the second derivatives //! -epsg1 is an angular tolerance in radians used for g1 continuity to compare the angle between the tangents //! -epsg2 is an angular tolerance in radians used for g2 continuity to compare the angle between the normals //! - percent : percentage of curvature variation (unitless) used for g2 continuity //! - maxlen is the maximum length of curv1 or curv2 in meters used to detect nul curvature (in mm) //! the constructor computes the quantities which are necessary to check the continuity in the following cases: //! case c0 -------- - the distance between p1 and p2 with p1=curv1 (u1) and p2=curv2(u2) //! case c1 ------- //! - the angle between the first derivatives dcurv1(u1)  dcurv2(u2) -------- and --------- du  du //! - the ratio between the magnitudes of the first derivatives //! the angle value is between 0 and pi/2 //! case c2 ------- - the angle between the second derivatives 2  2 d curv1(u1) d curv2(u2) ---------- ---------- 2  2 du du //! the angle value is between 0 and pi/2 //! - the ratio between the magnitudes of the second derivatives //! case g1 ------- the angle between the tangents at each point //! the angle value is between 0 and pi/2 //! case g2 ------- -the angle between the normals at each point //! the angle value is between 0 and pi/2 //! - the relative variation of curvature: |curvat1-curvat2| ------------------ 1/2 (curvat1*curvat2) //! where curvat1 is the curvature at the first point and curvat2 the curvature at the second point.

        Parameters
        ----------
        Curv1: Geom_Curve
        u1: float
        Curv2: Geom_Curve
        u2: float
        Order: GeomAbs_Shape
        EpsNul: float,optional
        	default value is 0.001
        EpsC0: float,optional
        	default value is 0.001
        EpsC1: float,optional
        	default value is 0.001
        EpsC2: float,optional
        	default value is 0.001
        EpsG1: float,optional
        	default value is 0.001
        EpsG2: float,optional
        	default value is 0.001
        Percent: float,optional
        	default value is 0.01
        Maxlen: float,optional
        	default value is 10000

        Returns
        -------
        None

        """
        _LocalAnalysis.LocalAnalysis_CurveContinuity_swiginit(self, _LocalAnalysis.new_LocalAnalysis_CurveContinuity(*args))

    def C0Value(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _LocalAnalysis.LocalAnalysis_CurveContinuity_C0Value(self, *args)

    def C1Angle(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _LocalAnalysis.LocalAnalysis_CurveContinuity_C1Angle(self, *args)

    def C1Ratio(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _LocalAnalysis.LocalAnalysis_CurveContinuity_C1Ratio(self, *args)

    def C2Angle(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _LocalAnalysis.LocalAnalysis_CurveContinuity_C2Angle(self, *args)

    def C2Ratio(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _LocalAnalysis.LocalAnalysis_CurveContinuity_C2Ratio(self, *args)

    def ContinuityStatus(self, *args) -> "GeomAbs_Shape":
        r"""
        No available documentation.

        Returns
        -------
        GeomAbs_Shape

        """
        return _LocalAnalysis.LocalAnalysis_CurveContinuity_ContinuityStatus(self, *args)

    def G1Angle(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _LocalAnalysis.LocalAnalysis_CurveContinuity_G1Angle(self, *args)

    def G2Angle(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _LocalAnalysis.LocalAnalysis_CurveContinuity_G2Angle(self, *args)

    def G2CurvatureVariation(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _LocalAnalysis.LocalAnalysis_CurveContinuity_G2CurvatureVariation(self, *args)

    def IsC0(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _LocalAnalysis.LocalAnalysis_CurveContinuity_IsC0(self, *args)

    def IsC1(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _LocalAnalysis.LocalAnalysis_CurveContinuity_IsC1(self, *args)

    def IsC2(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _LocalAnalysis.LocalAnalysis_CurveContinuity_IsC2(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _LocalAnalysis.LocalAnalysis_CurveContinuity_IsDone(self, *args)

    def IsG1(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _LocalAnalysis.LocalAnalysis_CurveContinuity_IsG1(self, *args)

    def IsG2(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _LocalAnalysis.LocalAnalysis_CurveContinuity_IsG2(self, *args)

    def StatusError(self, *args) -> "LocalAnalysis_StatusErrorType":
        r"""
        No available documentation.

        Returns
        -------
        LocalAnalysis_StatusErrorType

        """
        return _LocalAnalysis.LocalAnalysis_CurveContinuity_StatusError(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _LocalAnalysis.delete_LocalAnalysis_CurveContinuity

# Register LocalAnalysis_CurveContinuity in _LocalAnalysis:
_LocalAnalysis.LocalAnalysis_CurveContinuity_swigregister(LocalAnalysis_CurveContinuity)

class LocalAnalysis_SurfaceContinuity(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        -u1,v1 are the parameters of the point on surf1 -u2,v2 are the parameters of the point on surf2 -order is the required continuity: geomabs_c0 geomabs_c1 geomabs_c2 geomabs_g1 geomabs_g2 //! -epsnul is used to detect a a vector with nul magnitude //! -epsc0 is used for c0 continuity to confuse two points (in mm) //! -epsc1 is an angular tolerance in radians used for c1 continuity to compare the angle between the first derivatives //! -epsc2 is an angular tolerance in radians used for c2 continuity to compare the angle between the second derivatives //! -epsg1 is an angular tolerance in radians used for g1 continuity to compare the angle between the normals //! -percent : percentage of curvature variation (unitless) used for g2 continuity //! - maxlen is the maximum length of surf1 or surf2 in meters used to detect null curvature (in mm) //! the constructor computes the quantities which are necessary to check the continuity in the following cases: //! case c0 -------- - the distance between p1 and p2 with p1=surf (u1,v1) and p2=surfv2(u2,v2) //! case c1 ------- //! - the angle between the first derivatives in u : //! dsurf1(u1,v1) dsurf2(u2,v2) ----------- and --------- du  du //! the angle value is between 0 and pi/2 //! - the angle between the first derivatives in v : //! dsurf1(u1,v1) dsurf2(u2,v2) -------- and --------- dv  dv //! - the ratio between the magnitudes of the first derivatives in u - the ratio between the magnitudes of the first derivatives in v //! the angle value is between 0 and pi/2 //! case c2 ------- - the angle between the second derivatives in u 2 2 d surf1(u1,v1) d surf2(u2,v2) ---------- ---------- 2 2 d u d u //! - the ratio between the magnitudes of the second derivatives in u - the ratio between the magnitudes of the second derivatives in v //! the angle value is between 0 and pi/2 //! case g1 ------- -the angle between the normals at each point the angle value is between 0 and pi/2 //! case g2 ------- - the maximum normal curvature gap between the two points.

        Parameters
        ----------
        Surf1: Geom_Surface
        u1: float
        v1: float
        Surf2: Geom_Surface
        u2: float
        v2: float
        Order: GeomAbs_Shape
        EpsNul: float,optional
        	default value is 0.001
        EpsC0: float,optional
        	default value is 0.001
        EpsC1: float,optional
        	default value is 0.001
        EpsC2: float,optional
        	default value is 0.001
        EpsG1: float,optional
        	default value is 0.001
        Percent: float,optional
        	default value is 0.01
        Maxlen: float,optional
        	default value is 10000

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        curv1: Geom2d_Curve
        curv2: Geom2d_Curve
        U: float
        Surf1: Geom_Surface
        Surf2: Geom_Surface
        Order: GeomAbs_Shape
        EpsNul: float,optional
        	default value is 0.001
        EpsC0: float,optional
        	default value is 0.001
        EpsC1: float,optional
        	default value is 0.001
        EpsC2: float,optional
        	default value is 0.001
        EpsG1: float,optional
        	default value is 0.001
        Percent: float,optional
        	default value is 0.01
        Maxlen: float,optional
        	default value is 10000

        Returns
        -------
        None
        This constructor is used when we want to compute many analysis. after we use the method computeanalysis.

        Parameters
        ----------
        EpsNul: float,optional
        	default value is 0.001
        EpsC0: float,optional
        	default value is 0.001
        EpsC1: float,optional
        	default value is 0.001
        EpsC2: float,optional
        	default value is 0.001
        EpsG1: float,optional
        	default value is 0.001
        Percent: float,optional
        	default value is 0.01
        Maxlen: float,optional
        	default value is 10000

        Returns
        -------
        None

        """
        _LocalAnalysis.LocalAnalysis_SurfaceContinuity_swiginit(self, _LocalAnalysis.new_LocalAnalysis_SurfaceContinuity(*args))

    def C0Value(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _LocalAnalysis.LocalAnalysis_SurfaceContinuity_C0Value(self, *args)

    def C1UAngle(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _LocalAnalysis.LocalAnalysis_SurfaceContinuity_C1UAngle(self, *args)

    def C1URatio(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _LocalAnalysis.LocalAnalysis_SurfaceContinuity_C1URatio(self, *args)

    def C1VAngle(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _LocalAnalysis.LocalAnalysis_SurfaceContinuity_C1VAngle(self, *args)

    def C1VRatio(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _LocalAnalysis.LocalAnalysis_SurfaceContinuity_C1VRatio(self, *args)

    def C2UAngle(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _LocalAnalysis.LocalAnalysis_SurfaceContinuity_C2UAngle(self, *args)

    def C2URatio(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _LocalAnalysis.LocalAnalysis_SurfaceContinuity_C2URatio(self, *args)

    def C2VAngle(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _LocalAnalysis.LocalAnalysis_SurfaceContinuity_C2VAngle(self, *args)

    def C2VRatio(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _LocalAnalysis.LocalAnalysis_SurfaceContinuity_C2VRatio(self, *args)

    def ComputeAnalysis(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Surf1: GeomLProp_SLProps
        Surf2: GeomLProp_SLProps
        Order: GeomAbs_Shape

        Returns
        -------
        None

        """
        return _LocalAnalysis.LocalAnalysis_SurfaceContinuity_ComputeAnalysis(self, *args)

    def ContinuityStatus(self, *args) -> "GeomAbs_Shape":
        r"""
        No available documentation.

        Returns
        -------
        GeomAbs_Shape

        """
        return _LocalAnalysis.LocalAnalysis_SurfaceContinuity_ContinuityStatus(self, *args)

    def G1Angle(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _LocalAnalysis.LocalAnalysis_SurfaceContinuity_G1Angle(self, *args)

    def G2CurvatureGap(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _LocalAnalysis.LocalAnalysis_SurfaceContinuity_G2CurvatureGap(self, *args)

    def IsC0(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _LocalAnalysis.LocalAnalysis_SurfaceContinuity_IsC0(self, *args)

    def IsC1(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _LocalAnalysis.LocalAnalysis_SurfaceContinuity_IsC1(self, *args)

    def IsC2(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _LocalAnalysis.LocalAnalysis_SurfaceContinuity_IsC2(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _LocalAnalysis.LocalAnalysis_SurfaceContinuity_IsDone(self, *args)

    def IsG1(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _LocalAnalysis.LocalAnalysis_SurfaceContinuity_IsG1(self, *args)

    def IsG2(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _LocalAnalysis.LocalAnalysis_SurfaceContinuity_IsG2(self, *args)

    def StatusError(self, *args) -> "LocalAnalysis_StatusErrorType":
        r"""
        No available documentation.

        Returns
        -------
        LocalAnalysis_StatusErrorType

        """
        return _LocalAnalysis.LocalAnalysis_SurfaceContinuity_StatusError(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _LocalAnalysis.delete_LocalAnalysis_SurfaceContinuity

# Register LocalAnalysis_SurfaceContinuity in _LocalAnalysis:
_LocalAnalysis.LocalAnalysis_SurfaceContinuity_swigregister(LocalAnalysis_SurfaceContinuity)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.BVH import *
from OCC.Core.Graphic3d import *
from OCC.Core.gp import *
from OCC.Core.SelectMgr import *
from OCC.Core.Bnd import *
from OCC.Core.SelectBasics import *
from OCC.Core.TColgp import *
from OCC.Core.TopLoc import *
from OCC.Core.TColStd import *
from OCC.Core.Geom import *

#the following typedef cannot be wrapped as is
Select3D_BVHBuilder3d = NewType('Select3D_BVHBuilder3d', Any)
#the following typedef cannot be wrapped as is
Select3D_IndexedMapOfEntity = NewType('Select3D_IndexedMapOfEntity', Any)
#the following typedef cannot be wrapped as is
Select3D_Vec3 = NewType('Select3D_Vec3', Any)
#the following typedef cannot be wrapped as is
Select3D_VectorOfHPoly = NewType('Select3D_VectorOfHPoly', Any)
SelectBasics_SensitiveEntity = NewType('SelectBasics_SensitiveEntity', Select3D_SensitiveEntity)

class Select3D_EntitySequence:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class Select3D_TypeOfSensitivity(IntEnum):
	Select3D_TOS_INTERIOR: int = ...
	Select3D_TOS_BOUNDARY: int = ...
Select3D_TOS_INTERIOR = Select3D_TypeOfSensitivity.Select3D_TOS_INTERIOR
Select3D_TOS_BOUNDARY = Select3D_TypeOfSensitivity.Select3D_TOS_BOUNDARY

class Select3D_BVHIndexBuffer(Graphic3d_Buffer):
	def __init__(self, theAlloc: NCollection_BaseAllocator) -> None: ...
	def HasPatches(self) -> False: ...
	def Index(self, theIndex: int) -> int: ...
	def PatchSize(self, theIndex: int) -> int: ...
	@overload
	def SetIndex(self, theIndex: int, theValue: int) -> None: ...
	@overload
	def SetIndex(self, theIndex: int, theValue: int, thePatchSize: int) -> None: ...

class Select3D_Pnt:
	pass

class Select3D_PointData:
	def __init__(self, theNbPoints: int) -> None: ...
	def Pnt(self, theIndex: int) -> Select3D_Pnt: ...
	def Pnt3d(self, theIndex: int) -> gp_Pnt: ...
	@overload
	def SetPnt(self, theIndex: int, theValue: Select3D_Pnt) -> None: ...
	@overload
	def SetPnt(self, theIndex: int, theValue: gp_Pnt) -> None: ...
	def Size(self) -> int: ...

class Select3D_SensitiveBox(Select3D_SensitiveEntity):
	@overload
	def __init__(self, theOwnerId: SelectMgr_EntityOwner, theBox: Bnd_Box) -> None: ...
	@overload
	def __init__(self, theOwnerId: SelectMgr_EntityOwner, theXMin: float, theYMin: float, theZMin: float, theXMax: float, theYMax: float, theZMax: float) -> None: ...
	def BoundingBox(self) -> Select3D_BndBox3d: ...
	def CenterOfGeometry(self) -> gp_Pnt: ...
	def GetConnected(self) -> Select3D_SensitiveEntity: ...
	def Matches(self, theMgr: SelectBasics_SelectingVolumeManager, thePickResult: SelectBasics_PickResult) -> bool: ...
	def NbSubElements(self) -> int: ...
	def ToBuildBVH(self) -> bool: ...

class Select3D_SensitiveFace(Select3D_SensitiveEntity):
	@overload
	def __init__(self, theOwnerId: SelectMgr_EntityOwner, thePoints: TColgp_Array1OfPnt, theType: Select3D_TypeOfSensitivity) -> None: ...
	@overload
	def __init__(self, theOwnerId: SelectMgr_EntityOwner, thePoints: TColgp_HArray1OfPnt, theType: Select3D_TypeOfSensitivity) -> None: ...
	def BVH(self) -> None: ...
	def BoundingBox(self) -> Select3D_BndBox3d: ...
	def CenterOfGeometry(self) -> gp_Pnt: ...
	def GetConnected(self) -> Select3D_SensitiveEntity: ...
	def GetPoints(self, theHArrayOfPnt: TColgp_HArray1OfPnt) -> None: ...
	def Matches(self, theMgr: SelectBasics_SelectingVolumeManager, thePickResult: SelectBasics_PickResult) -> bool: ...
	def NbSubElements(self) -> int: ...
	def ToBuildBVH(self) -> bool: ...

class Select3D_SensitivePoint(Select3D_SensitiveEntity):
	def __init__(self, theOwnerId: SelectMgr_EntityOwner, thePoint: gp_Pnt) -> None: ...
	def BoundingBox(self) -> Select3D_BndBox3d: ...
	def CenterOfGeometry(self) -> gp_Pnt: ...
	def GetConnected(self) -> Select3D_SensitiveEntity: ...
	def Matches(self, theMgr: SelectBasics_SelectingVolumeManager, thePickResult: SelectBasics_PickResult) -> bool: ...
	def NbSubElements(self) -> int: ...
	def Point(self) -> gp_Pnt: ...
	def ToBuildBVH(self) -> bool: ...

class Select3D_SensitiveSegment(Select3D_SensitiveEntity):
	def __init__(self, theOwnerId: SelectMgr_EntityOwner, theFirstPnt: gp_Pnt, theLastPnt: gp_Pnt) -> None: ...
	def BoundingBox(self) -> Select3D_BndBox3d: ...
	def CenterOfGeometry(self) -> gp_Pnt: ...
	@overload
	def EndPoint(self) -> gp_Pnt: ...
	@overload
	def EndPoint(self, thePnt: gp_Pnt) -> None: ...
	def GetConnected(self) -> Select3D_SensitiveEntity: ...
	def Matches(self, theMgr: SelectBasics_SelectingVolumeManager, thePickResult: SelectBasics_PickResult) -> bool: ...
	def NbSubElements(self) -> int: ...
	def SetEndPoint(self, thePnt: gp_Pnt) -> None: ...
	def SetStartPoint(self, thePnt: gp_Pnt) -> None: ...
	@overload
	def StartPoint(self) -> gp_Pnt: ...
	@overload
	def StartPoint(self, thePnt: gp_Pnt) -> None: ...
	def ToBuildBVH(self) -> bool: ...

class Select3D_SensitiveTriangle(Select3D_SensitiveEntity):
	def __init__(self, theOwnerId: SelectMgr_EntityOwner, thePnt0: gp_Pnt, thePnt1: gp_Pnt, thePnt2: gp_Pnt, theType: Optional[Select3D_TypeOfSensitivity] = Select3D_TOS_INTERIOR) -> None: ...
	def BoundingBox(self) -> Select3D_BndBox3d: ...
	def Center3D(self) -> gp_Pnt: ...
	def CenterOfGeometry(self) -> gp_Pnt: ...
	def GetConnected(self) -> Select3D_SensitiveEntity: ...
	def Matches(self, theMgr: SelectBasics_SelectingVolumeManager, thePickResult: SelectBasics_PickResult) -> bool: ...
	def NbSubElements(self) -> int: ...
	def Points3D(self, thePnt0: gp_Pnt, thePnt1: gp_Pnt, thePnt2: gp_Pnt) -> None: ...
	def ToBuildBVH(self) -> bool: ...

class Select3D_InteriorSensitivePointSet(Select3D_SensitiveSet):
	def __init__(self, theOwnerId: SelectMgr_EntityOwner, thePoints: TColgp_Array1OfPnt) -> None: ...
	def BoundingBox(self) -> Select3D_BndBox3d: ...
	def Box(self, theIdx: int) -> Select3D_BndBox3d: ...
	def Center(self, theIdx: int, theAxis: int) -> float: ...
	def CenterOfGeometry(self) -> gp_Pnt: ...
	def GetPoints(self, theHArrayOfPnt: TColgp_HArray1OfPnt) -> None: ...
	def NbSubElements(self) -> int: ...
	def Size(self) -> int: ...
	def Swap(self, theIdx1: int, theIdx2: int) -> None: ...

class Select3D_SensitiveGroup(Select3D_SensitiveSet):
	@overload
	def __init__(self, theOwnerId: SelectMgr_EntityOwner, theIsMustMatchAll: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, theOwnerId: SelectMgr_EntityOwner, theEntities: Select3D_EntitySequence, theIsMustMatchAll: Optional[bool] = True) -> None: ...
	@overload
	def Add(self, theEntities: Select3D_EntitySequence) -> None: ...
	@overload
	def Add(self, theSensitive: Select3D_SensitiveEntity) -> None: ...
	def BoundingBox(self) -> Select3D_BndBox3d: ...
	def Box(self, theIdx: int) -> Select3D_BndBox3d: ...
	def Center(self, theIdx: int, theAxis: int) -> float: ...
	def CenterOfGeometry(self) -> gp_Pnt: ...
	def Clear(self) -> None: ...
	def Entities(self) -> Select3D_IndexedMapOfEntity: ...
	def GetConnected(self) -> Select3D_SensitiveEntity: ...
	def IsIn(self, theSensitive: Select3D_SensitiveEntity) -> bool: ...
	def LastDetectedEntity(self) -> Select3D_SensitiveEntity: ...
	def LastDetectedEntityIndex(self) -> int: ...
	def Matches(self, theMgr: SelectBasics_SelectingVolumeManager, thePickResult: SelectBasics_PickResult) -> bool: ...
	def MustMatchAll(self) -> bool: ...
	def NbSubElements(self) -> int: ...
	def Remove(self, theSensitive: Select3D_SensitiveEntity) -> None: ...
	def Set(self, theOwnerId: SelectMgr_EntityOwner) -> None: ...
	def SetCheckOverlapAll(self, theToCheckAll: bool) -> None: ...
	def SetMatchType(self, theIsMustMatchAll: bool) -> None: ...
	def Size(self) -> int: ...
	def SubEntity(self, theIndex: int) -> Select3D_SensitiveEntity: ...
	def Swap(self, theIdx1: int, theIdx2: int) -> None: ...
	def ToCheckOverlapAll(self) -> bool: ...

class Select3D_SensitivePoly(Select3D_SensitiveSet):
	@overload
	def __init__(self, theOwnerId: SelectMgr_EntityOwner, thePoints: TColgp_Array1OfPnt, theIsBVHEnabled: bool) -> None: ...
	@overload
	def __init__(self, theOwnerId: SelectMgr_EntityOwner, thePoints: TColgp_HArray1OfPnt, theIsBVHEnabled: bool) -> None: ...
	@overload
	def __init__(self, theOwnerId: SelectMgr_EntityOwner, theIsBVHEnabled: bool, theNbPnts: Optional[int] = 6) -> None: ...
	def ArrayBounds(self) -> Tuple[int, int]: ...
	def BoundingBox(self) -> Select3D_BndBox3d: ...
	def Box(self, theIdx: int) -> Select3D_BndBox3d: ...
	def Center(self, theIdx: int, theAxis: int) -> float: ...
	def CenterOfGeometry(self) -> gp_Pnt: ...
	def GetPoint3d(self, thePntIdx: int) -> gp_Pnt: ...
	def NbSubElements(self) -> int: ...
	def Points3D(self, theHArrayOfPnt: TColgp_HArray1OfPnt) -> None: ...
	def Size(self) -> int: ...
	def Swap(self, theIdx1: int, theIdx2: int) -> None: ...

class Select3D_SensitivePrimitiveArray(Select3D_SensitiveSet):
	def __init__(self, theOwnerId: SelectMgr_EntityOwner) -> None: ...
	def BVH(self) -> None: ...
	def BoundingBox(self) -> Select3D_BndBox3d: ...
	def Box(self, theIdx: int) -> Select3D_BndBox3d: ...
	def Center(self, theIdx: int, theAxis: int) -> float: ...
	def CenterOfGeometry(self) -> gp_Pnt: ...
	def GetConnected(self) -> Select3D_SensitiveEntity: ...
	def HasInitLocation(self) -> bool: ...
	def InvInitLocation(self) -> gp_GTrsf: ...
	def LastDetectedEdgeNode1(self) -> int: ...
	def LastDetectedEdgeNode2(self) -> int: ...
	def LastDetectedElement(self) -> int: ...
	def LastDetectedElementMap(self) -> TColStd_HPackedMapOfInteger: ...
	def LastDetectedNode(self) -> int: ...
	def LastDetectedNodeMap(self) -> TColStd_HPackedMapOfInteger: ...
	def Matches(self, theMgr: SelectBasics_SelectingVolumeManager, thePickResult: SelectBasics_PickResult) -> bool: ...
	def NbSubElements(self) -> int: ...
	def PatchDistance(self) -> False: ...
	def PatchSizeMax(self) -> int: ...
	def Set(self, theOwnerId: SelectMgr_EntityOwner) -> None: ...
	def SetPatchSizeMax(self, thePatchSizeMax: int) -> None: ...
	def Size(self) -> int: ...
	def Swap(self, theIdx1: int, theIdx2: int) -> None: ...
	def ToDetectEdges(self) -> False: ...
	def ToDetectElementMap(self) -> False: ...
	def ToDetectElements(self) -> False: ...
	def ToDetectNodeMap(self) -> False: ...
	def ToDetectNodes(self) -> False: ...

class Select3D_SensitiveWire(Select3D_SensitiveSet):
	def __init__(self, theOwnerId: SelectMgr_EntityOwner) -> None: ...
	def Add(self, theSensitive: Select3D_SensitiveEntity) -> None: ...
	def BoundingBox(self) -> Select3D_BndBox3d: ...
	def Box(self, theIdx: int) -> Select3D_BndBox3d: ...
	def Center(self, theIdx: int, theAxis: int) -> float: ...
	def CenterOfGeometry(self) -> gp_Pnt: ...
	def GetConnected(self) -> Select3D_SensitiveEntity: ...
	def GetEdges(self) -> False: ...
	def GetLastDetected(self) -> Select3D_SensitiveEntity: ...
	def NbSubElements(self) -> int: ...
	def Set(self, theOwnerId: SelectMgr_EntityOwner) -> None: ...
	def Size(self) -> int: ...
	def Swap(self, theIdx1: int, theIdx2: int) -> None: ...

class Select3D_SensitiveCircle(Select3D_SensitivePoly):
	@overload
	def __init__(self, theOwnerId: SelectMgr_EntityOwner, theCircle: gp_Circ, theIsFilled: Optional[bool] = False, theNbPnts: Optional[int] = 12) -> None: ...
	@overload
	def __init__(self, theOwnerId: SelectMgr_EntityOwner, theCircle: gp_Circ, theU1: float, theU2: float, theIsFilled: Optional[bool] = False, theNbPnts: Optional[int] = 12) -> None: ...
	@overload
	def __init__(self, theOwnerId: SelectMgr_EntityOwner, thePnts3d: TColgp_HArray1OfPnt, theIsFilled: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, theOwnerId: SelectMgr_EntityOwner, thePnts3d: TColgp_Array1OfPnt, theIsFilled: Optional[bool] = False) -> None: ...
	def BVH(self) -> None: ...
	def CenterOfGeometry(self) -> gp_Pnt: ...
	def GetConnected(self) -> Select3D_SensitiveEntity: ...
	def Matches(self, theMgr: SelectBasics_SelectingVolumeManager, thePickResult: SelectBasics_PickResult) -> bool: ...
	def ToBuildBVH(self) -> bool: ...

class Select3D_SensitiveCurve(Select3D_SensitivePoly):
	@overload
	def __init__(self, theOwnerId: SelectMgr_EntityOwner, theCurve: Geom_Curve, theNbPnts: Optional[int] = 17) -> None: ...
	@overload
	def __init__(self, theOwnerId: SelectMgr_EntityOwner, thePoints: TColgp_HArray1OfPnt) -> None: ...
	@overload
	def __init__(self, theOwnerId: SelectMgr_EntityOwner, thePoints: TColgp_Array1OfPnt) -> None: ...
	def GetConnected(self) -> Select3D_SensitiveEntity: ...

#classnotwrapped
class Select3D_SensitiveTriangulation: ...

#classnotwrapped
class Select3D_SensitiveEntity: ...

#classnotwrapped
class Handle_Select3D_SensitiveEntity: ...

#classnotwrapped
class Select3D_SensitiveSet: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TColStd import *
from OCC.Core.Adaptor3d import *
from OCC.Core.GeomAbs import *
from OCC.Core.TColgp import *


class Law_Laws:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class law:
	@overload
	@staticmethod
	def MixBnd(Lin: Law_Linear) -> Law_BSpFunc: ...
	@overload
	@staticmethod
	def MixBnd(Degree: int, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, Lin: Law_Linear) -> TColStd_HArray1OfReal: ...
	@staticmethod
	def MixTgt(Degree: int, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, NulOnTheRight: bool, Index: int) -> TColStd_HArray1OfReal: ...
	@staticmethod
	def Reparametrize(Curve: Adaptor3d_Curve, First: float, Last: float, HasDF: bool, HasDL: bool, DFirst: float, DLast: float, Rev: bool, NbPoints: int) -> Law_BSpline: ...
	@staticmethod
	def Scale(First: float, Last: float, HasF: bool, HasL: bool, VFirst: float, VLast: float) -> Law_BSpline: ...
	@staticmethod
	def ScaleCub(First: float, Last: float, HasF: bool, HasL: bool, VFirst: float, VLast: float) -> Law_BSpline: ...

class Law_BSpline(Standard_Transient):
	@overload
	def __init__(self, Poles: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Multiplicities: TColStd_Array1OfInteger, Degree: int, Periodic: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, Poles: TColStd_Array1OfReal, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Multiplicities: TColStd_Array1OfInteger, Degree: int, Periodic: Optional[bool] = False) -> None: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Copy(self) -> Law_BSpline: ...
	def D0(self, U: float) -> float: ...
	def D1(self, U: float) -> Tuple[float, float]: ...
	def D2(self, U: float) -> Tuple[float, float, float]: ...
	def D3(self, U: float) -> Tuple[float, float, float, float]: ...
	def DN(self, U: float, N: int) -> float: ...
	def Degree(self) -> int: ...
	def EndPoint(self) -> float: ...
	def FirstParameter(self) -> float: ...
	def FirstUKnotIndex(self) -> int: ...
	def IncreaseDegree(self, Degree: int) -> None: ...
	@overload
	def IncreaseMultiplicity(self, Index: int, M: int) -> None: ...
	@overload
	def IncreaseMultiplicity(self, I1: int, I2: int, M: int) -> None: ...
	def IncrementMultiplicity(self, I1: int, I2: int, M: int) -> None: ...
	def InsertKnot(self, U: float, M: Optional[int] = 1, ParametricTolerance: Optional[float] = 0.0, Add: Optional[bool] = True) -> None: ...
	def InsertKnots(self, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, ParametricTolerance: Optional[float] = 0.0, Add: Optional[bool] = False) -> None: ...
	def IsCN(self, N: int) -> bool: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def IsRational(self) -> bool: ...
	def Knot(self, Index: int) -> float: ...
	def KnotDistribution(self) -> GeomAbs_BSplKnotDistribution: ...
	def KnotSequence(self, K: TColStd_Array1OfReal) -> None: ...
	def Knots(self, K: TColStd_Array1OfReal) -> None: ...
	def LastParameter(self) -> float: ...
	def LastUKnotIndex(self) -> int: ...
	def LocalD0(self, U: float, FromK1: int, ToK2: int) -> float: ...
	def LocalD1(self, U: float, FromK1: int, ToK2: int) -> Tuple[float, float]: ...
	def LocalD2(self, U: float, FromK1: int, ToK2: int) -> Tuple[float, float, float]: ...
	def LocalD3(self, U: float, FromK1: int, ToK2: int) -> Tuple[float, float, float, float]: ...
	def LocalDN(self, U: float, FromK1: int, ToK2: int, N: int) -> float: ...
	def LocalValue(self, U: float, FromK1: int, ToK2: int) -> float: ...
	def LocateU(self, U: float, ParametricTolerance: float, WithKnotRepetition: Optional[bool] = False) -> Tuple[int, int]: ...
	@staticmethod
	def MaxDegree() -> int: ...
	def MovePointAndTangent(self, U: float, NewValue: float, Derivative: float, Tolerance: float, StartingCondition: int, EndingCondition: int) -> int: ...
	def Multiplicities(self, M: TColStd_Array1OfInteger) -> None: ...
	def Multiplicity(self, Index: int) -> int: ...
	def NbKnots(self) -> int: ...
	def NbPoles(self) -> int: ...
	def PeriodicNormalization(self) -> float: ...
	def Pole(self, Index: int) -> float: ...
	def Poles(self, P: TColStd_Array1OfReal) -> None: ...
	def RemoveKnot(self, Index: int, M: int, Tolerance: float) -> bool: ...
	def Resolution(self, Tolerance3D: float) -> float: ...
	def Reverse(self) -> None: ...
	def ReversedParameter(self, U: float) -> float: ...
	def Segment(self, U1: float, U2: float) -> None: ...
	@overload
	def SetKnot(self, Index: int, K: float) -> None: ...
	@overload
	def SetKnot(self, Index: int, K: float, M: int) -> None: ...
	def SetKnots(self, K: TColStd_Array1OfReal) -> None: ...
	def SetNotPeriodic(self) -> None: ...
	def SetOrigin(self, Index: int) -> None: ...
	def SetPeriodic(self) -> None: ...
	@overload
	def SetPole(self, Index: int, P: float) -> None: ...
	@overload
	def SetPole(self, Index: int, P: float, Weight: float) -> None: ...
	def SetWeight(self, Index: int, Weight: float) -> None: ...
	def StartPoint(self) -> float: ...
	def Value(self, U: float) -> float: ...
	def Weight(self, Index: int) -> float: ...
	def Weights(self, W: TColStd_Array1OfReal) -> None: ...

class Law_BSplineKnotSplitting:
	def __init__(self, BasisLaw: Law_BSpline, ContinuityRange: int) -> None: ...
	def NbSplits(self) -> int: ...
	def SplitValue(self, Index: int) -> int: ...
	def Splitting(self, SplitValues: TColStd_Array1OfInteger) -> None: ...

class Law_Function(Standard_Transient):
	def Bounds(self) -> Tuple[float, float]: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def D1(self, X: float) -> Tuple[float, float]: ...
	def D2(self, X: float) -> Tuple[float, float, float]: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def Trim(self, PFirst: float, PLast: float, Tol: float) -> Law_Function: ...
	def Value(self, X: float) -> float: ...

class Law_Interpolate:
	@overload
	def __init__(self, Points: TColStd_HArray1OfReal, PeriodicFlag: bool, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Points: TColStd_HArray1OfReal, Parameters: TColStd_HArray1OfReal, PeriodicFlag: bool, Tolerance: float) -> None: ...
	def Curve(self) -> Law_BSpline: ...
	def IsDone(self) -> bool: ...
	@overload
	def Load(self, InitialTangent: float, FinalTangent: float) -> None: ...
	@overload
	def Load(self, Tangents: TColStd_Array1OfReal, TangentFlags: TColStd_HArray1OfBoolean) -> None: ...
	def Perform(self) -> None: ...

class Law_BSpFunc(Law_Function):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: Law_BSpline, First: float, Last: float) -> None: ...
	def Bounds(self) -> Tuple[float, float]: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Curve(self) -> Law_BSpline: ...
	def D1(self, X: float) -> Tuple[float, float]: ...
	def D2(self, X: float) -> Tuple[float, float, float]: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def SetCurve(self, C: Law_BSpline) -> None: ...
	def Trim(self, PFirst: float, PLast: float, Tol: float) -> Law_Function: ...
	def Value(self, X: float) -> float: ...

class Law_Composite(Law_Function):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, First: float, Last: float, Tol: float) -> None: ...
	def Bounds(self) -> Tuple[float, float]: ...
	def ChangeElementaryLaw(self, W: float) -> Law_Function: ...
	def ChangeLaws(self) -> Law_Laws: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def D1(self, X: float) -> Tuple[float, float]: ...
	def D2(self, X: float) -> Tuple[float, float, float]: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def IsPeriodic(self) -> bool: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def SetPeriodic(self) -> None: ...
	def Trim(self, PFirst: float, PLast: float, Tol: float) -> Law_Function: ...
	def Value(self, X: float) -> float: ...

class Law_Constant(Law_Function):
	def __init__(self) -> None: ...
	def Bounds(self) -> Tuple[float, float]: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def D1(self, X: float) -> Tuple[float, float]: ...
	def D2(self, X: float) -> Tuple[float, float, float]: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def Set(self, Radius: float, PFirst: float, PLast: float) -> None: ...
	def Trim(self, PFirst: float, PLast: float, Tol: float) -> Law_Function: ...
	def Value(self, X: float) -> float: ...

class Law_Linear(Law_Function):
	def __init__(self) -> None: ...
	def Bounds(self) -> Tuple[float, float]: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def D1(self, X: float) -> Tuple[float, float]: ...
	def D2(self, X: float) -> Tuple[float, float, float]: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def Set(self, Pdeb: float, Valdeb: float, Pfin: float, Valfin: float) -> None: ...
	def Trim(self, PFirst: float, PLast: float, Tol: float) -> Law_Function: ...
	def Value(self, X: float) -> float: ...

class Law_Interpol(Law_BSpFunc):
	def __init__(self) -> None: ...
	@overload
	def Set(self, ParAndRad: TColgp_Array1OfPnt2d, Periodic: Optional[bool] = False) -> None: ...
	@overload
	def Set(self, ParAndRad: TColgp_Array1OfPnt2d, Dd: float, Df: float, Periodic: Optional[bool] = False) -> None: ...
	@overload
	def SetInRelative(self, ParAndRad: TColgp_Array1OfPnt2d, Ud: float, Uf: float, Periodic: Optional[bool] = False) -> None: ...
	@overload
	def SetInRelative(self, ParAndRad: TColgp_Array1OfPnt2d, Ud: float, Uf: float, Dd: float, Df: float, Periodic: Optional[bool] = False) -> None: ...

class Law_S(Law_BSpFunc):
	def __init__(self) -> None: ...
	@overload
	def Set(self, Pdeb: float, Valdeb: float, Pfin: float, Valfin: float) -> None: ...
	@overload
	def Set(self, Pdeb: float, Valdeb: float, Ddeb: float, Pfin: float, Valfin: float, Dfin: float) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

law_MixBnd = law.MixBnd
law_MixBnd = law.MixBnd
law_MixTgt = law.MixTgt
law_Reparametrize = law.Reparametrize
law_Scale = law.Scale
law_ScaleCub = law.ScaleCub
Law_BSpline_MaxDegree = Law_BSpline.MaxDegree



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
XmlLDrivers module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_xmlldrivers.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _XmlLDrivers
else:
    import _XmlLDrivers

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _XmlLDrivers.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _XmlLDrivers.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlLDrivers.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlLDrivers.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _XmlLDrivers.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _XmlLDrivers.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _XmlLDrivers.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _XmlLDrivers.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _XmlLDrivers.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _XmlLDrivers.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlLDrivers.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _XmlLDrivers.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _XmlLDrivers.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlLDrivers.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlLDrivers.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlLDrivers.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _XmlLDrivers.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _XmlLDrivers:
_XmlLDrivers.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _XmlLDrivers.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.XmlMDF
import OCC.Core.TDF
import OCC.Core.XmlObjMgt
import OCC.Core.LDOM
import OCC.Core.gp
import OCC.Core.Storage
import OCC.Core.TDocStd
import OCC.Core.CDF
import OCC.Core.CDM
import OCC.Core.Resource
import OCC.Core.PCDM

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_XmlLDrivers_DocumentRetrievalDriver_Create() -> "opencascade::handle< XmlLDrivers_DocumentRetrievalDriver >":
    return _XmlLDrivers.Handle_XmlLDrivers_DocumentRetrievalDriver_Create()

def Handle_XmlLDrivers_DocumentRetrievalDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlLDrivers_DocumentRetrievalDriver >":
    return _XmlLDrivers.Handle_XmlLDrivers_DocumentRetrievalDriver_DownCast(t)

def Handle_XmlLDrivers_DocumentRetrievalDriver_IsNull(t: "opencascade::handle< XmlLDrivers_DocumentRetrievalDriver > const &") -> "bool":
    return _XmlLDrivers.Handle_XmlLDrivers_DocumentRetrievalDriver_IsNull(t)

def Handle_XmlLDrivers_DocumentStorageDriver_Create() -> "opencascade::handle< XmlLDrivers_DocumentStorageDriver >":
    return _XmlLDrivers.Handle_XmlLDrivers_DocumentStorageDriver_Create()

def Handle_XmlLDrivers_DocumentStorageDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlLDrivers_DocumentStorageDriver >":
    return _XmlLDrivers.Handle_XmlLDrivers_DocumentStorageDriver_DownCast(t)

def Handle_XmlLDrivers_DocumentStorageDriver_IsNull(t: "opencascade::handle< XmlLDrivers_DocumentStorageDriver > const &") -> "bool":
    return _XmlLDrivers.Handle_XmlLDrivers_DocumentStorageDriver_IsNull(t)
class XmlLDrivers_SequenceOfNamespaceDef(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< XmlLDrivers_NamespaceDef >::iterator":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_begin(self)

    def end(self) -> "NCollection_Sequence< XmlLDrivers_NamespaceDef >::iterator":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_end(self)

    def cbegin(self) -> "NCollection_Sequence< XmlLDrivers_NamespaceDef >::const_iterator":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_cbegin(self)

    def cend(self) -> "NCollection_Sequence< XmlLDrivers_NamespaceDef >::const_iterator":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_cend(self)

    def __init__(self, *args):
        _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_swiginit(self, _XmlLDrivers.new_XmlLDrivers_SequenceOfNamespaceDef(*args))

    def Size(self) -> "Standard_Integer":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_Size(self)

    def Length(self) -> "Standard_Integer":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_IsEmpty(self)

    def Reverse(self) -> "void":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "TDF_HAllocator") -> "void":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_delNode(theNode, theAl)

    def Clear(self, theAllocator: "TDF_HAllocator"=0) -> "void":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_Clear(self, theAllocator)

    def Assign(self, theOther: "XmlLDrivers_SequenceOfNamespaceDef") -> "NCollection_Sequence< XmlLDrivers_NamespaceDef > &":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_Assign(self, theOther)

    def Set(self, theOther: "XmlLDrivers_SequenceOfNamespaceDef") -> "NCollection_Sequence< XmlLDrivers_NamespaceDef > &":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "XmlLDrivers_SequenceOfNamespaceDef") -> "void":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_Split(self, theIndex, theSeq)

    def First(self) -> "XmlLDrivers_NamespaceDef const &":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_First(self)

    def ChangeFirst(self) -> "XmlLDrivers_NamespaceDef &":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_ChangeFirst(self)

    def Last(self) -> "XmlLDrivers_NamespaceDef const &":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_Last(self)

    def ChangeLast(self) -> "XmlLDrivers_NamespaceDef &":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "XmlLDrivers_NamespaceDef const &":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "XmlLDrivers_NamespaceDef &":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "XmlLDrivers_NamespaceDef &":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "XmlLDrivers_NamespaceDef") -> "void":
        return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _XmlLDrivers.delete_XmlLDrivers_SequenceOfNamespaceDef

    def __len__(self):
        return self.Size()


# Register XmlLDrivers_SequenceOfNamespaceDef in _XmlLDrivers:
_XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_swigregister(XmlLDrivers_SequenceOfNamespaceDef)

def XmlLDrivers_SequenceOfNamespaceDef_delNode(theNode: "NCollection_SeqNode *", theAl: "TDF_HAllocator") -> "void":
    return _XmlLDrivers.XmlLDrivers_SequenceOfNamespaceDef_delNode(theNode, theAl)

class xmlldrivers(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AttributeDrivers(*args) -> "opencascade::handle< XmlMDF_ADriverTable >":
        r"""
        No available documentation.

        Parameters
        ----------
        theMsgDriver: Message_Messenger

        Returns
        -------
        opencascade::handle<XmlMDF_ADriverTable>

        """
        return _XmlLDrivers.xmlldrivers_AttributeDrivers(*args)

    @staticmethod
    def CreationDate(*args) -> "TCollection_AsciiString":
        r"""
        No available documentation.

        Returns
        -------
        TCollection_AsciiString

        """
        return _XmlLDrivers.xmlldrivers_CreationDate(*args)

    @staticmethod
    def DefineFormat(*args) -> "void":
        r"""
        Defines format 'xmllocaf' and registers its read and write drivers in the specified application.

        Parameters
        ----------
        theApp: TDocStd_Application

        Returns
        -------
        None

        """
        return _XmlLDrivers.xmlldrivers_DefineFormat(*args)

    @staticmethod
    def Factory(*args) -> "opencascade::handle< Standard_Transient > const &":
        r"""
        No available documentation.

        Parameters
        ----------
        theGUID: Standard_GUID

        Returns
        -------
        opencascade::handle<Standard_Transient>

        """
        return _XmlLDrivers.xmlldrivers_Factory(*args)

    @staticmethod
    def StorageVersion(*args) -> "int":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _XmlLDrivers.xmlldrivers_StorageVersion(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _XmlLDrivers.xmlldrivers_swiginit(self, _XmlLDrivers.new_xmlldrivers())
    __swig_destroy__ = _XmlLDrivers.delete_xmlldrivers

# Register xmlldrivers in _XmlLDrivers:
_XmlLDrivers.xmlldrivers_swigregister(xmlldrivers)

def xmlldrivers_AttributeDrivers(*args) -> "opencascade::handle< XmlMDF_ADriverTable >":
    r"""
    No available documentation.

    Parameters
    ----------
    theMsgDriver: Message_Messenger

    Returns
    -------
    opencascade::handle<XmlMDF_ADriverTable>

    """
    return _XmlLDrivers.xmlldrivers_AttributeDrivers(*args)

def xmlldrivers_CreationDate(*args) -> "TCollection_AsciiString":
    r"""
    No available documentation.

    Returns
    -------
    TCollection_AsciiString

    """
    return _XmlLDrivers.xmlldrivers_CreationDate(*args)

def xmlldrivers_DefineFormat(*args) -> "void":
    r"""
    Defines format 'xmllocaf' and registers its read and write drivers in the specified application.

    Parameters
    ----------
    theApp: TDocStd_Application

    Returns
    -------
    None

    """
    return _XmlLDrivers.xmlldrivers_DefineFormat(*args)

def xmlldrivers_Factory(*args) -> "opencascade::handle< Standard_Transient > const &":
    r"""
    No available documentation.

    Parameters
    ----------
    theGUID: Standard_GUID

    Returns
    -------
    opencascade::handle<Standard_Transient>

    """
    return _XmlLDrivers.xmlldrivers_Factory(*args)

def xmlldrivers_StorageVersion(*args) -> "int":
    r"""
    No available documentation.

    Returns
    -------
    int

    """
    return _XmlLDrivers.xmlldrivers_StorageVersion(*args)

class XmlLDrivers_DocumentRetrievalDriver(OCC.Core.PCDM.PCDM_RetrievalDriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _XmlLDrivers.XmlLDrivers_DocumentRetrievalDriver_swiginit(self, _XmlLDrivers.new_XmlLDrivers_DocumentRetrievalDriver(*args))

    def AttributeDrivers(self, *args) -> "opencascade::handle< XmlMDF_ADriverTable >":
        r"""
        No available documentation.

        Parameters
        ----------
        theMsgDriver: Message_Messenger

        Returns
        -------
        opencascade::handle<XmlMDF_ADriverTable>

        """
        return _XmlLDrivers.XmlLDrivers_DocumentRetrievalDriver_AttributeDrivers(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlLDrivers_DocumentRetrievalDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlLDrivers.delete_XmlLDrivers_DocumentRetrievalDriver

# Register XmlLDrivers_DocumentRetrievalDriver in _XmlLDrivers:
_XmlLDrivers.XmlLDrivers_DocumentRetrievalDriver_swigregister(XmlLDrivers_DocumentRetrievalDriver)

class XmlLDrivers_DocumentStorageDriver(OCC.Core.PCDM.PCDM_StorageDriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theCopyright: TCollection_ExtendedString

        Returns
        -------
        None

        """
        _XmlLDrivers.XmlLDrivers_DocumentStorageDriver_swiginit(self, _XmlLDrivers.new_XmlLDrivers_DocumentStorageDriver(*args))

    def AttributeDrivers(self, *args) -> "opencascade::handle< XmlMDF_ADriverTable >":
        r"""
        No available documentation.

        Parameters
        ----------
        theMsgDriver: Message_Messenger

        Returns
        -------
        opencascade::handle<XmlMDF_ADriverTable>

        """
        return _XmlLDrivers.XmlLDrivers_DocumentStorageDriver_AttributeDrivers(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlLDrivers_DocumentStorageDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlLDrivers.delete_XmlLDrivers_DocumentStorageDriver

# Register XmlLDrivers_DocumentStorageDriver in _XmlLDrivers:
_XmlLDrivers.XmlLDrivers_DocumentStorageDriver_swigregister(XmlLDrivers_DocumentStorageDriver)

class XmlLDrivers_NamespaceDef(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        thePrefix: TCollection_AsciiString
        theURI: TCollection_AsciiString

        Returns
        -------
        None

        """
        _XmlLDrivers.XmlLDrivers_NamespaceDef_swiginit(self, _XmlLDrivers.new_XmlLDrivers_NamespaceDef(*args))

    def Prefix(self, *args) -> "TCollection_AsciiString const &":
        r"""
        No available documentation.

        Returns
        -------
        TCollection_AsciiString

        """
        return _XmlLDrivers.XmlLDrivers_NamespaceDef_Prefix(self, *args)

    def URI(self, *args) -> "TCollection_AsciiString const &":
        r"""
        No available documentation.

        Returns
        -------
        TCollection_AsciiString

        """
        return _XmlLDrivers.XmlLDrivers_NamespaceDef_URI(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _XmlLDrivers.delete_XmlLDrivers_NamespaceDef

# Register XmlLDrivers_NamespaceDef in _XmlLDrivers:
_XmlLDrivers.XmlLDrivers_NamespaceDef_swigregister(XmlLDrivers_NamespaceDef)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TDocStd import *
from OCC.Core.XmlDrivers import *
from OCC.Core.Message import *
from OCC.Core.XmlMDF import *
from OCC.Core.TCollection import *


class xmlxcafdrivers:
	@staticmethod
	def DefineFormat(theApp: TDocStd_Application) -> None: ...
	@staticmethod
	def Factory(aGUID: Standard_GUID) -> Standard_Transient: ...

class XmlXCAFDrivers_DocumentRetrievalDriver(XmlDrivers_DocumentRetrievalDriver):
	def __init__(self) -> None: ...
	def AttributeDrivers(self, theMsgDriver: Message_Messenger) -> XmlMDF_ADriverTable: ...

class XmlXCAFDrivers_DocumentStorageDriver(XmlDrivers_DocumentStorageDriver):
	def __init__(self, theCopyright: TCollection_ExtendedString) -> None: ...
	def AttributeDrivers(self, theMsgDriver: Message_Messenger) -> XmlMDF_ADriverTable: ...

# harray1 classes
# harray2 classes
# hsequence classes

xmlxcafdrivers_DefineFormat = xmlxcafdrivers.DefineFormat
xmlxcafdrivers_Factory = xmlxcafdrivers.Factory
